MapDataset

Struct MapDataset 

pub struct MapDataset<D: Dataset> { /* private fields */ }
Wraps a dataset and applies a Transform lazily on each get().

Implementations

Source

impl<D: Dataset> MapDataset<D>

pub fn new( inner: D, transform: Box<dyn Transform>, feat_shape: Vec<usize>, tgt_shape: Vec<usize>, ) -> Self

Create a MapDataset.

feat_shape and tgt_shape describe the shapes after the transform is applied. If the transform doesn’t change shapes, you can clone them from the inner dataset.

pub fn same_shape(inner: D, transform: Box<dyn Transform>) -> Self

Convenience: create a MapDataset whose shapes are unchanged.