Structs
- Compose
- Chain multiple transforms.
- Normalize
- Normalize features to [0, 1] by dividing by a given scale factor.
- OneHot
Encode - One-hot encode the target label into a vector of size
num_classes. - Reshape
Features - Reshape the feature tensor to a different shape (without changing data).
- Standardize
- Standardize features to zero mean and unit variance.
Traits
- Transform
- A transform applied to each sample before batching.